@@ -6,7 +6,7 @@ from enum import Enum
 from pickle import dumps, loads
 from tempfile import NamedTemporaryFile
 from types import TracebackType
-from typing import Callable, Generic, Optional, Type, TypeVar, Union, cast
+from typing import IO, Generic, Optional, Type, TypeVar, Union, cast
 from uuid import uuid4
 
 from .logger import logger
@@ -15,8 +15,9 @@ if sys.version_info >= (3, 9):
     from contextlib import AbstractContextManager
 
     ContextManager = AbstractContextManager
+    from collections.abc import Callable
 else:
-    from typing import ContextManager
+    from typing import Callable, ContextManager
 
 T = TypeVar("T")
 KT = TypeVar("KT")
@@ -33,6 +34,10 @@ class RebuildStrategy(Enum):
 
 def sanitize_table_name(table_name: str, prefix: str) -> str:
     ret = "".join(c for c in table_name if c.isalnum() or c == "_")
+    if len(ret) == 0:
+        ret = create_random_name(prefix)
+    if ret[0].isnumeric():
+        ret = f"{prefix}_{ret}"
     if ret != table_name:
         logger.warning(f"The table name is changed to {ret} due to illegal characters")
     return ret
@@ -46,6 +51,27 @@ def is_hashable(x: object) -> bool:
     return isinstance(x, Hashable)
 
 
+def create_temporary_db_file() -> IO[bytes]:
+    return NamedTemporaryFile(prefix="sc_", suffix=".db")
+
+
+def create_tempfile_connection() -> sqlite3.Connection:
+    return sqlite3.connect(create_temporary_db_file().name)
+
+
+def tidy_connection(connection: Optional[Union[str, sqlite3.Connection]] = None) -> sqlite3.Connection:
+    if connection is None:
+        return create_tempfile_connection()
+    elif isinstance(connection, str):
+        return sqlite3.connect(connection)
+    elif isinstance(connection, sqlite3.Connection):
+        return connection
+    else:
+        raise TypeError(
+            f"connection argument must be None or a string or a sqlite3.Connection, not '{type(connection)}'"
+        )
+
+
 class TemporaryTableContext(ContextManager[str]):
     def __init__(self, cur: sqlite3.Cursor, reference_table_name: str):
         self._cursor = cur
@@ -180,17 +206,8 @@ class SqliteCollectionBase(Generic[T], metaclass=ABCMeta):
         super(SqliteCollectionBase, self).__init__()
         self._serializer = self._default_serializer if serializer is None else serializer
         self._deserializer = self._default_deserializer if deserializer is None else deserializer
+        self._connection = tidy_connection(connection)
         self._persist = persist
-        if connection is None:
-            self._connection = sqlite3.connect(NamedTemporaryFile().name)
-        elif isinstance(connection, str):
-            self._connection = sqlite3.connect(connection)
-        elif isinstance(connection, sqlite3.Connection):
-            self._connection = connection
-        else:
-            raise TypeError(
-                f"connection argument must be None or a string or a sqlite3.Connection, not '{type(connection)}'"
-            )
         self._table_name = (
             sanitize_table_name(create_random_name(self.container_type_name), self.container_type_name)
             if table_name is None
@@ -256,11 +273,12 @@ class SqliteCollectionBase(Generic[T], metaclass=ABCMeta):
     def table_name(self, table_name: str) -> None:
         cur = self.connection.cursor()
         new_table_name = sanitize_table_name(table_name, self.container_type_name)
-        try:
-            self._driver_class.alter_table_name(self.table_name, new_table_name, cur)
-        except sqlite3.IntegrityError as e:
-            raise ValueError(table_name)
-        self._table_name = new_table_name
+        if self._table_name != new_table_name:
+            try:
+                self._driver_class.alter_table_name(self.table_name, new_table_name, cur)
+            except sqlite3.IntegrityError as e:
+                raise ValueError(table_name)
+            self._table_name = new_table_name
 
     @property
     def connection(self) -> sqlite3.Connection:
